==> webkit2gtk_2.44.2.orig.tar.xz: webkitgtk-2.44.2/Source/WebKit/UIProcess/Notifications/WebNotificationProvider.h <==
/*
 * Copyright (C) 2011 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef WebNotificationProvider_h
#define WebNotificationProvider_h

#include "APIClient.h"
#include "APINotificationProvider.h"
#include "WKNotificationProvider.h"
#include <wtf/Forward.h>

namespace API {
template<> struct ClientTraits<WKNotificationProviderBase> {
    typedef std::tuple<WKNotificationProviderV0> Versions;
};
}

namespace WebKit {

class WebNotification;
class WebNotificationManagerProxy;
class WebPageProxy;

class WebNotificationProvider : public API::NotificationProvider, public API::Client<WKNotificationProviderBase> {
    WTF_MAKE_FAST_ALLOCATED;
public:
    explicit WebNotificationProvider(const WKNotificationProviderBase*);

    bool show(WebPageProxy*, WebNotification&, RefPtr<WebCore::NotificationResources>&&) override;
    void cancel(WebNotification&) override;
    void didDestroyNotification(WebNotification&) override;
    void clearNotifications(const Vector<uint64_t>& notificationIDs) override;

    void addNotificationManager(WebNotificationManagerProxy&) override;
    void removeNotificationManager(WebNotificationManagerProxy&) override;

    HashMap<WTF::String, bool> notificationPermissions() override;
};

} // namespace WebKit

#endif // WebNotificationProvider_h

==> webkit2gtk_2.45.3.orig.tar.xz: webkitgtk-2.45.3/Source/WebKit/UIProcess/Notifications/WebNotificationProvider.h <==
/*
 * Copyright (C) 2011 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef WebNotificationProvider_h
#define WebNotificationProvider_h

#include "APIClient.h"
#include "APINotificationProvider.h"
#include "WKNotificationProvider.h"
#include <wtf/Forward.h>

namespace API {
template<> struct ClientTraits<WKNotificationProviderBase> {
    typedef std::tuple<WKNotificationProviderV0> Versions;
};
}

namespace WebKit {

class WebNotification;
class WebNotificationManagerProxy;
class WebPageProxy;

class WebNotificationProvider : public API::NotificationProvider, public API::Client<WKNotificationProviderBase> {
    WTF_MAKE_FAST_ALLOCATED;
public:
    explicit WebNotificationProvider(const WKNotificationProviderBase*);

    bool show(WebPageProxy*, WebNotification&, RefPtr<WebCore::NotificationResources>&&) override;
    void cancel(WebNotification&) override;
    void didDestroyNotification(WebNotification&) override;
    void clearNotifications(const Vector<WebNotificationIdentifier>&) override;

    void addNotificationManager(WebNotificationManagerProxy&) override;
    void removeNotificationManager(WebNotificationManagerProxy&) override;

    HashMap<WTF::String, bool> notificationPermissions() override;
};

} // namespace WebKit

#endif // WebNotificationProvider_h
